@@ -1,12 +1,12 @@
 /*
-  Copyright (C) 2008 by Eike Hein <hein@kde.org>
+  Copyright (C) 2008-2009 by Eike Hein <hein@kde.org>
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of
   the License or (at your option) version 3 or any later version
   accepted by the membership of KDE e.V. (or its successor appro-
-  ved by the membership of KDE e.V.), which shall act as a proxy 
+  ved by the membership of KDE e.V.), which shall act as a proxy
   defined in Section 14 of version 3 of the license.
 
   This program is distributed in the hope that it will be useful,
@@ -23,18 +23,19 @@
 #define APPLICATION_H
 
 
-#include "mainwindow.h"
-
 #include <KUniqueApplication>
 
 
+class MainWindow;
+
+
 class Application : public KUniqueApplication
 {
     Q_OBJECT
 
     public:
         explicit Application();
-#ifdef Q_WS_X11
+#if defined(Q_WS_X11) && !KDE_IS_VERSION(4,2,68)
         explicit Application(Display* display, Qt::HANDLE visual, Qt::HANDLE colormap);
 #endif
         virtual ~Application();
@@ -42,10 +43,6 @@ class Application : public KUniqueApplication
         virtual int newInstance();
 
     private:
-        void init();
-
-        bool m_firstInstance;
-
         MainWindow* m_mainWindow;
 };
 
