@@ -7,7 +7,7 @@
   published by the Free Software Foundation; either version 2 of
   the License or (at your option) version 3 or any later version
   accepted by the membership of KDE e.V. (or its successor appro-
-  ved by the membership of KDE e.V.), which shall act as a proxy 
+  ved by the membership of KDE e.V.), which shall act as a proxy
   defined in Section 14 of version 3 of the license.
 
   This program is distributed in the hope that it will be useful,
@@ -36,11 +36,16 @@
 #include <KHelpMenu>
 #include <KMenu>
 #include <KMessageBox>
-#include <KPassivePopup>
+#if KDE_IS_VERSION(4,3,95)
+    #include <KNotification>
+#else
+    #include <KPassivePopup>
+#endif
 #include <KShortcutsDialog>
 #include <KStandardAction>
 #include <KToggleFullScreenAction>
 #include <KVBox>
+#include <KGlobalSettings>
 
 #include <QDesktopWidget>
 #include <QPainter>
@@ -56,7 +61,7 @@
 #endif
 
 
-MainWindow::MainWindow(QWidget* parent) 
+MainWindow::MainWindow(QWidget* parent)
     : KMainWindow(parent, Qt::CustomizeWindowHint | Qt::FramelessWindowHint)
 {
     QDBusConnection::sessionBus().registerObject("/yakuake/window", this, QDBusConnection::ExportScriptableSlots);
@@ -83,11 +88,11 @@ MainWindow::MainWindow(QWidget* parent)
     connect(m_tabBar, SIGNAL(requestRemoveTerminalHighlight()), m_sessionStack, SIGNAL(removeTerminalHighlight()));
     connect(m_tabBar, SIGNAL(tabContextMenuClosed()), m_sessionStack, SIGNAL(removeTerminalHighlight()));
 
-    connect(m_sessionStack, SIGNAL(sessionAdded(int, const QString&)), 
+    connect(m_sessionStack, SIGNAL(sessionAdded(int, const QString&)),
         m_tabBar, SLOT(addTab(int, const QString&)));
     connect(m_sessionStack, SIGNAL(sessionRaised(int)), m_tabBar, SLOT(selectTab(int)));
     connect(m_sessionStack, SIGNAL(sessionRemoved(int)), m_tabBar, SLOT(removeTab(int)));
-    connect(m_sessionStack, SIGNAL(activeTitleChanged(const QString&)),  
+    connect(m_sessionStack, SIGNAL(activeTitleChanged(const QString&)),
         m_titleBar, SLOT(setTitle(const QString&)));
 
     connect(&m_mousePoller, SIGNAL(timeout()), this, SLOT(pollMouse()));
@@ -165,10 +170,11 @@ void MainWindow::setupActions()
     m_actionCollection->addAction("view-full-screen", fullScreenAction);
     connect(fullScreenAction, SIGNAL(toggled(bool)), this, SLOT(setFullScreen(bool)));
 
-    KAction* action = KStandardAction::quit(kapp, SLOT(quit()),actionCollection());
+    KAction* action = KStandardAction::quit(this, SLOT(close()), actionCollection());
     action->setShortcut(QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_Q));
 
     action = KStandardAction::aboutApp(m_helpMenu, SLOT(aboutApplication()), actionCollection());
+    action = KStandardAction::reportBug(m_helpMenu, SLOT(reportBug()), actionCollection());
     action = KStandardAction::aboutKDE(m_helpMenu, SLOT(aboutKDE()), actionCollection());
 
     action = KStandardAction::keyBindings(this, SLOT(configureKeys()), actionCollection());
@@ -378,8 +384,13 @@ void MainWindow::handleContextDependentToggleAction(bool checked, QAction* actio
     if (action == actionCollection()->action("toggle-session-keyboard-input"))
         m_sessionStack->setSessionKeyboardInputEnabled(sessionId, !checked);
 
-    if (action == actionCollection()->action("toggle-session-prevent-closing"))
+    if (action == actionCollection()->action("toggle-session-prevent-closing")) {
         m_sessionStack->setSessionClosable(sessionId, !checked);
+
+        // Repaint the tab bar when the Prevent Closing action is toggled
+        // so the lock icon is added to or removed from the tab label.
+        m_tabBar->repaint();
+    }
 }
 
 void MainWindow::setContextDependentActionsQuiet(bool quiet)
@@ -414,6 +425,7 @@ void MainWindow::setupMenu()
 {
     m_menu->addTitle(i18nc("@title:menu", "Help"));
     m_menu->addAction(actionCollection()->action(KStandardAction::stdName(KStandardAction::WhatsThis)));
+    m_menu->addAction(actionCollection()->action(KStandardAction::stdName(KStandardAction::ReportBug)));
     m_menu->addAction(actionCollection()->action(KStandardAction::stdName(KStandardAction::AboutApp)));
     m_menu->addAction(actionCollection()->action(KStandardAction::stdName(KStandardAction::AboutKDE)));
 
@@ -542,7 +554,7 @@ void MainWindow::configureApp()
 
     WindowSettings* windowSettings = new WindowSettings(settingsDialog);
     settingsDialog->addPage(windowSettings, i18nc("@title Preferences page name", "Window"), "yakuake");
-    connect(windowSettings, SIGNAL(updateWindowGeometry(int, int, int)), 
+    connect(windowSettings, SIGNAL(updateWindowGeometry(int, int, int)),
         this, SLOT(setWindowGeometry(int, int, int)));
 
     QWidget* behaviorSettings = new QWidget(settingsDialog);
@@ -552,7 +564,7 @@ void MainWindow::configureApp()
         "preferences-other");
 
     AppearanceSettings* appearanceSettings = new AppearanceSettings(settingsDialog);
-    settingsDialog->addPage(appearanceSettings, i18nc("@title Preferences page name", "Appearance"), 
+    settingsDialog->addPage(appearanceSettings, i18nc("@title Preferences page name", "Appearance"),
         "preferences-desktop-theme");
     connect(appearanceSettings, SIGNAL(settingsChanged()), this, SLOT(applySettings()));
     connect(settingsDialog, SIGNAL(closeClicked()), appearanceSettings, SLOT(resetSelection()));
@@ -565,14 +577,14 @@ void MainWindow::applySettings()
 {
     if (Settings::dynamicTabTitles())
     {
-        connect(m_sessionStack, SIGNAL(titleChanged(int, const QString&)), 
+        connect(m_sessionStack, SIGNAL(titleChanged(int, const QString&)),
             m_tabBar, SLOT(setTabTitle(int, const QString&)));
 
         m_sessionStack->emitTitles();
     }
     else
     {
-        disconnect(m_sessionStack, SIGNAL(titleChanged(int, const QString&)), 
+        disconnect(m_sessionStack, SIGNAL(titleChanged(int, const QString&)),
             m_tabBar, SLOT(setTabTitle(int, const QString&)));
     }
 
@@ -604,7 +616,7 @@ void MainWindow::applySkin()
 
     if (!gotSkin)
     {
-        KMessageBox::error(parentWidget(), 
+        KMessageBox::error(parentWidget(),
             i18nc("@info", "<application>Yakuake</application> was unable to load a skin. It is likely that it was installed incorrectly.<nl/><nl/>"
                            "The application will now quit."),
             i18nc("@title:window", "Cannot Load Skin"));
@@ -669,11 +681,11 @@ void MainWindow::setWindowGeometry(int newWidth, int newHeight, int newPosition)
     if (Settings::showTabBar())
     {
         maxHeight -= m_tabBar->height();
-        m_tabBar->setGeometry(m_skin->borderWidth(), maxHeight, 
+        m_tabBar->setGeometry(m_skin->borderWidth(), maxHeight,
             width() - 2 * m_skin->borderWidth(), m_tabBar->height());
     }
 
-    m_sessionStack->setGeometry(m_skin->borderWidth(), 0, 
+    m_sessionStack->setGeometry(m_skin->borderWidth(), 0,
         width() - 2 * m_skin->borderWidth(), maxHeight);
 
     updateMask();
@@ -684,7 +696,7 @@ void MainWindow::setScreen(QAction* action)
     Settings::setScreen(action->data().toInt());
 
     applyWindowGeometry();
-    
+
     updateScreenMenu();
 }
 
@@ -772,7 +784,7 @@ void MainWindow::paintEvent(QPaintEvent* event)
     QRect leftBorder(0, 0, m_skin->borderWidth(), height() - m_titleBar->height());
     painter.fillRect(leftBorder, m_skin->borderColor());
 
-    QRect rightBorder(width() - m_skin->borderWidth(), 0, m_skin->borderWidth(), 
+    QRect rightBorder(width() - m_skin->borderWidth(), 0, m_skin->borderWidth(),
         height() - m_titleBar->height());
     painter.fillRect(rightBorder, m_skin->borderColor());
 
@@ -949,15 +961,46 @@ int MainWindow::getScreen()
 
 QRect MainWindow::getDesktopGeometry()
 {
+    QRect screenGeometry = KApplication::desktop()->screenGeometry(getScreen());
+    
     QAction* action = actionCollection()->action("view-full-screen");
 
-    if (action->isChecked()) 
-        return KApplication::desktop()->screenGeometry(getScreen());
+    if (action->isChecked())
+        return screenGeometry;
 
-    if (KApplication::desktop()->numScreens() > 1) 
-        return KWindowSystem::workArea().intersect(KApplication::desktop()->screenGeometry(getScreen()));
+    int currentDesktop = KWindowSystem::windowInfo(winId(), NET::CurrentDesktop).desktop();
+    
+    if (KApplication::desktop()->numScreens() > 1)
+    {
+        const QList<WId> allWindows = KWindowSystem::windows();
+        QList<WId> offScreenWindows;
 
-    return KWindowSystem::workArea();
+        QListIterator<WId> i(allWindows);
+
+        while (i.hasNext())
+        {
+            WId windowId = i.next();
+
+            if (KWindowSystem::hasWId(windowId))
+            {
+                KWindowInfo windowInfo = KWindowSystem::windowInfo(windowId, 0, NET::WM2ExtendedStrut);
+                
+                if (windowInfo.valid() && windowInfo.desktop() == currentDesktop)
+                {
+                    NETExtendedStrut strut = windowInfo.extendedStrut();
+
+                    QRect topStrut(strut.top_start, 0, strut.top_end, strut.top_width);
+
+                    if (!topStrut.intersects(screenGeometry))
+                        offScreenWindows << windowId;
+                }
+            }
+        }
+
+        return KWindowSystem::workArea(offScreenWindows, currentDesktop).intersect(screenGeometry);
+    }
+
+    return KWindowSystem::workArea(currentDesktop);
 }
 
 void MainWindow::whatsThis()
@@ -968,19 +1011,23 @@ void MainWindow::whatsThis()
 void MainWindow::showStartupPopup()
 {
     KAction* action = static_cast<KAction*>(actionCollection()->action("toggle-window-state"));
-    QString shortcut = action->globalShortcut().toString();
+    QString shortcut(action->globalShortcut().toString());
+    QString title(i18nc("@title:window", "<application>Yakuake</application> Notification"));
+    QString message(i18nc("@info", "Application successfully started.<nl/>" "Press <shortcut>%1</shortcut> to use it ...", shortcut));
 
+#if KDE_IS_VERSION(4,3,95)
+    KNotification::event(KNotification::Notification, title, message,
+        KIconLoader::global()->loadIcon("yakuake", KIconLoader::Desktop));
+#else
     KPassivePopup* popup = new KPassivePopup();
 
     popup->setAutoDelete(true);
     popup->setTimeout(5000);
-    popup->setView(popup->standardView(i18nc("@title:window", 
-        "<application>Yakuake</application> Notification"), 
-        i18nc("@info", "Application successfully started.<nl/>"
-                       "Press <shortcut>%1</shortcut> to use it...", shortcut),
+    popup->setView(popup->standardView(title, message,
         KIconLoader::global()->loadIcon("yakuake", KIconLoader::Small)));
 
     popup->show(getDesktopGeometry().topLeft());
+#endif
 }
 
 void MainWindow::showFirstRunDialog()
@@ -1009,7 +1056,7 @@ void MainWindow::firstRunDialogOk()
 {
     KAction* action = static_cast<KAction*>(actionCollection()->action("toggle-window-state"));
 
-    action->setGlobalShortcut(KShortcut(m_firstRunDialog->keySequence()), 
+    action->setGlobalShortcut(KShortcut(m_firstRunDialog->keySequence()),
         KAction::ActiveShortcut, KAction::NoAutoloading);
 
     actionCollection()->writeSettings();
