@@ -1,5 +1,6 @@
 /*
-  Copyright (C) 2008 by Eike Hein <hein@kde.org>
+  Copyright (C) 2008-2009 by Eike Hein <hein@kde.org>
+  Copyright (C) 2009 by Juan Carlos Torres <carlosdgtorres@gmail.com>
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
@@ -56,19 +57,22 @@ class MainWindow : public KMainWindow
         ~MainWindow();
 
         KActionCollection* actionCollection() { return m_actionCollection; }
+        SessionStack* sessionStack() { return m_sessionStack; }
 
         Skin* skin() { return m_skin; }
         KMenu* menu() { return m_menu; }
 
         bool useTranslucency() { return m_useTranslucency; }
 
-        void setContextDependendActionsQuiet(bool quiet);
+        void setContextDependentActionsQuiet(bool quiet);
 
 
     public slots:
         Q_SCRIPTABLE void toggleWindowState();
 
-        void handleContextDependendAction(QAction* action = 0, int sessionId = -1);
+        void handleContextDependentAction(QAction* action = 0, int sessionId = -1);
+        void handleContextDependentToggleAction(bool checked, QAction* action = 0, int sessionId = -1);
+        void handleToggleTerminalKeyboardInput(bool checked);
 
 
     protected:
@@ -108,7 +112,6 @@ class MainWindow : public KMainWindow
         void setKeepOpen(bool keepOpen);
 
         void setFullScreen(bool state);
-        void updateFullScreen();
 
         void handleSwitchToAction();
 
@@ -142,7 +145,7 @@ class MainWindow : public KMainWindow
         bool m_useTranslucency;
 
         KActionCollection* m_actionCollection;
-        QList<KAction*> m_contextDependendActions;
+        QList<KAction*> m_contextDependentActions;
 
         Skin* m_skin;
         TitleBar* m_titleBar;
