@@ -1,5 +1,6 @@
 /*
-  Copyright (C) 2008 by Eike Hein <hein@kde.org>
+  Copyright (C) 2008-2009 by Eike Hein <hein@kde.org>
+  Copyright (C) 2009 by Juan Carlos Torres <carlosdgtorres@gmail.com>
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
@@ -25,12 +26,13 @@
 
 #include "session.h"
 
+
 #include <QHash>
 #include <QStackedWidget>
 
 
 class Session;
-
+class VisualEventOverlay;
 
 class SessionStack : public QStackedWidget
 {
@@ -45,11 +47,10 @@ class SessionStack : public QStackedWidget
 
         void editProfile(int sessionId = -1);
 
-        void splitLeftRight(int sessionId = -1);
-        void splitTopBottom(int sessionId = -1);
-
         void emitTitles();
 
+        bool requiresVisualEventOverlay();
+
 
     public slots:
         Q_SCRIPTABLE void addSession(Session::SessionType type = Session::Single);
@@ -62,14 +63,33 @@ class SessionStack : public QStackedWidget
         Q_SCRIPTABLE void removeSession(int sessionId);
         Q_SCRIPTABLE void removeTerminal(int terminalId);
 
+        Q_SCRIPTABLE void splitSessionLeftRight(int sessionId);
+        Q_SCRIPTABLE void splitSessionTopBottom(int sessionId);
+        Q_SCRIPTABLE void splitTerminalLeftRight(int terminalId);
+        Q_SCRIPTABLE void splitTerminalTopBottom(int terminalId);
+
         Q_SCRIPTABLE int activeSessionId() { return m_activeSessionId; }
         Q_SCRIPTABLE int activeTerminalId();
+
         Q_SCRIPTABLE const QString sessionIdList();
         Q_SCRIPTABLE const QString terminalIdList();
+        Q_SCRIPTABLE const QString terminalIdsForSessionId(int sessionId);
+        Q_SCRIPTABLE int sessionIdForTerminalId(int terminalId);
 
         Q_SCRIPTABLE void runCommand(const QString& command);
         Q_SCRIPTABLE void runCommandInTerminal(int terminalId, const QString& command);
 
+        Q_SCRIPTABLE bool isSessionKeyboardInputEnabled(int sessionId);
+        Q_SCRIPTABLE void setSessionKeyboardInputEnabled(int sessionId, bool enabled);
+        Q_SCRIPTABLE bool isTerminalKeyboardInputEnabled(int terminalId);
+        Q_SCRIPTABLE void setTerminalKeyboardInputEnabled(int terminalId, bool enabled);
+
+        Q_SCRIPTABLE bool isSessionClosable(int sessionId);
+        Q_SCRIPTABLE void setSessionClosable(int sessionId, bool closable);
+        Q_SCRIPTABLE bool hasUnclosableSessions() const;
+
+        void handleTerminalHighlightRequest(int terminalId);
+
 
     signals:
         void sessionAdded(int sessionId, const QString& title = 0);
@@ -86,12 +106,21 @@ class SessionStack : public QStackedWidget
 
         void manageProfiles();
 
+        void removeTerminalHighlight();
+
 
     private slots:
+        void handleManualTerminalActivation(Terminal*);
+
         void cleanup(int sessionId);
 
 
     private:
+        enum QueryCloseType { QueryCloseSession, QueryCloseTerminal };
+        bool queryClose(int sessionId, QueryCloseType type);
+
+        VisualEventOverlay* m_visualEventOverlay;
+
         int m_activeSessionId;
 
         QHash<int, Session*> m_sessions;
