@@ -6,7 +6,7 @@
   published by the Free Software Foundation; either version 2 of
   the License or (at your option) version 3 or any later version
   accepted by the membership of KDE e.V. (or its successor appro-
-  ved by the membership of KDE e.V.), which shall act as a proxy 
+  ved by the membership of KDE e.V.), which shall act as a proxy
   defined in Section 14 of version 3 of the license.
 
   This program is distributed in the hope that it will be useful,
@@ -23,13 +23,15 @@
 
 #include <KConfig>
 #include <KConfigGroup>
+#include <KIcon>
+#include <KGlobalSettings>
 #include <KStandardDirs>
 
 #include <QFileInfo>
 #include <QUrl>
 
 
-Skin::Skin() 
+Skin::Skin()
 {
 }
 
@@ -45,6 +47,10 @@ bool Skin::load(const QString& name)
     if (!QFile::exists(titlePath) || !QFile::exists(tabPath))
         return false;
 
+    // FIXME: Use Qt::UniqueConnection once we depend on Qt 4.6.
+    disconnect(KGlobalSettings::self(), SIGNAL(iconChanged(int)), this, SLOT(systemIconsChanged(int)));
+    connect(KGlobalSettings::self(), SIGNAL(iconChanged(int)), this, SLOT(systemIconsChanged(int)));
+
     QString titleDir(QFileInfo(titlePath).absolutePath());
     QString tabDir(QFileInfo(tabPath).absolutePath());
 
@@ -54,8 +60,8 @@ bool Skin::load(const QString& name)
 
     KConfigGroup border = titleConfig.group("Border");
 
-    m_borderColor = QColor(border.readEntry("red", 0), 
-                           border.readEntry("green", 0), 
+    m_borderColor = QColor(border.readEntry("red", 0),
+                           border.readEntry("green", 0),
                            border.readEntry("blue", 0));
 
     m_borderWidth = border.readEntry("width", 1);
@@ -71,7 +77,7 @@ bool Skin::load(const QString& name)
     KConfigGroup titleBarFocusButton = titleConfig.group("FocusButton");
 
     m_titleBarFocusButtonPosition.setX(titleBarFocusButton.readEntry("x", 0));
-    m_titleBarFocusButtonPosition.setY(titleBarFocusButton.readEntry("y", 0));  
+    m_titleBarFocusButtonPosition.setY(titleBarFocusButton.readEntry("y", 0));
 
     m_titleBarFocusButtonStyleSheet = buttonStyleSheet(titleDir + titleBarFocusButton.readEntry("up_image", ""),
                                                        titleDir + titleBarFocusButton.readEntry("over_image", ""),
@@ -81,7 +87,7 @@ bool Skin::load(const QString& name)
     KConfigGroup titleBarMenuButton = titleConfig.group("ConfigButton");
 
     m_titleBarMenuButtonPosition.setX(titleBarMenuButton.readEntry("x", 0));
-    m_titleBarMenuButtonPosition.setY(titleBarMenuButton.readEntry("y", 0));  
+    m_titleBarMenuButtonPosition.setY(titleBarMenuButton.readEntry("y", 0));
 
     m_titleBarMenuButtonStyleSheet = buttonStyleSheet(titleDir + titleBarMenuButton.readEntry("up_image", ""),
                                                         titleDir + titleBarMenuButton.readEntry("over_image", ""),
@@ -91,7 +97,7 @@ bool Skin::load(const QString& name)
     KConfigGroup titleBarQuitButton = titleConfig.group("QuitButton");
 
     m_titleBarQuitButtonPosition.setX(titleBarQuitButton.readEntry("x", 0));
-    m_titleBarQuitButtonPosition.setY(titleBarQuitButton.readEntry("y", 0));  
+    m_titleBarQuitButtonPosition.setY(titleBarQuitButton.readEntry("y", 0));
 
     m_titleBarQuitButtonStyleSheet = buttonStyleSheet(titleDir + titleBarQuitButton.readEntry("up_image", ""),
                                                       titleDir + titleBarQuitButton.readEntry("over_image", ""),
@@ -103,10 +109,10 @@ bool Skin::load(const QString& name)
     m_titleBarText = titleBarText.readEntry("text", "");
 
     m_titleBarTextPosition.setX(titleBarText.readEntry("x", 0));
-    m_titleBarTextPosition.setY(titleBarText.readEntry("y", 0));  
+    m_titleBarTextPosition.setY(titleBarText.readEntry("y", 0));
 
-    m_titleBarTextColor = QColor(titleBarText.readEntry("red", 0), 
-                                 titleBarText.readEntry("green", 0), 
+    m_titleBarTextColor = QColor(titleBarText.readEntry("red", 0),
+                                 titleBarText.readEntry("green", 0),
                                  titleBarText.readEntry("blue", 0));
 
 
@@ -114,10 +120,10 @@ bool Skin::load(const QString& name)
     KConfigGroup tabBar = tabConfig.group("Tabs");
 
     m_tabBarPosition.setX(tabBar.readEntry("x", 0));
-    m_tabBarPosition.setY(tabBar.readEntry("y", 0)); 
+    m_tabBarPosition.setY(tabBar.readEntry("y", 0));
 
-    m_tabBarTextColor = QColor(tabBar.readEntry("red", 0), 
-                               tabBar.readEntry("green", 0), 
+    m_tabBarTextColor = QColor(tabBar.readEntry("red", 0),
+                               tabBar.readEntry("green", 0),
                                tabBar.readEntry("blue", 0));
 
     m_tabBarSeparatorImage.load(tabDir + tabBar.readEntry("separator_image", ""));
@@ -126,6 +132,10 @@ bool Skin::load(const QString& name)
     m_tabBarSelectedLeftCornerImage.load(tabDir + tabBar.readEntry("selected_left_corner", ""));
     m_tabBarSelectedRightCornerImage.load(tabDir + tabBar.readEntry("selected_right_corner", ""));
 
+    m_tabBarPreventClosingImage.load(tabDir + tabBar.readEntry("prevent_closing_image", ""));
+    m_tabBarPreventClosingImagePosition.setX(tabBar.readEntry("prevent_closing_image_x", 0));
+    m_tabBarPreventClosingImagePosition.setY(tabBar.readEntry("prevent_closing_image_y", 0));
+
 
     KConfigGroup tabBarBackground = tabConfig.group("Background");
 
@@ -137,7 +147,7 @@ bool Skin::load(const QString& name)
     KConfigGroup tabBarNewTabButton = tabConfig.group("PlusButton");
 
     m_tabBarNewTabButtonPosition.setX(tabBarNewTabButton.readEntry("x", 0));
-    m_tabBarNewTabButtonPosition.setY(tabBarNewTabButton.readEntry("y", 0));  
+    m_tabBarNewTabButtonPosition.setY(tabBarNewTabButton.readEntry("y", 0));
 
     m_tabBarNewTabButtonStyleSheet = buttonStyleSheet(tabDir + tabBarNewTabButton.readEntry("up_image", ""),
                                                       tabDir + tabBarNewTabButton.readEntry("over_image", ""),
@@ -147,12 +157,14 @@ bool Skin::load(const QString& name)
     KConfigGroup tabBarCloseTabButton = tabConfig.group("MinusButton");
 
     m_tabBarCloseTabButtonPosition.setX(tabBarCloseTabButton.readEntry("x", 0));
-    m_tabBarCloseTabButtonPosition.setY(tabBarCloseTabButton.readEntry("y", 0));  
+    m_tabBarCloseTabButtonPosition.setY(tabBarCloseTabButton.readEntry("y", 0));
 
     m_tabBarCloseTabButtonStyleSheet = buttonStyleSheet(tabDir + tabBarCloseTabButton.readEntry("up_image", ""),
                                                         tabDir + tabBarCloseTabButton.readEntry("over_image", ""),
                                                         tabDir + tabBarCloseTabButton.readEntry("down_image", ""));
 
+    if (m_tabBarPreventClosingImage.isNull())
+        updateTabBarPreventClosingImageCache();
 
     return true;
 }
@@ -185,3 +197,43 @@ const QString Skin::buttonStyleSheet(const QString& up, const QString& over, con
 
     return styleSheet;
 }
+
+const QPixmap Skin::tabBarPreventClosingImage()
+{
+    if (m_tabBarPreventClosingImage.isNull())
+        return m_tabBarPreventClosingImageCached;
+
+    return m_tabBarPreventClosingImage;
+}
+
+void Skin::updateTabBarPreventClosingImageCache()
+{
+    // Get the target image size from the tabBar height, acquired from
+    // background image, minus (2 * y position) of the lock icon.
+    int m_IconSize = m_tabBarBackgroundImage.height() -
+        (2 * m_tabBarPreventClosingImagePosition.y());
+
+    // Get the system lock icon in a generous size.
+    m_tabBarPreventClosingImageCached = KIcon("object-locked.png").pixmap(48, 48);
+
+    // Resize the image if it's too tall.
+    if (m_IconSize <  m_tabBarPreventClosingImageCached.height())
+    {
+        m_tabBarPreventClosingImageCached =
+            m_tabBarPreventClosingImageCached.scaled(m_IconSize,
+            m_IconSize, Qt::KeepAspectRatio,
+            Qt::SmoothTransformation);
+    }
+}
+
+void Skin::systemIconsChanged(int group)
+{
+    Q_UNUSED(group);
+
+    if (m_tabBarPreventClosingImage.isNull())
+    {
+        updateTabBarPreventClosingImageCache();
+
+        emit iconChanged();
+    }
+}
