@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2008 by Eike Hein <hein@kde.org>
+  Copyright (C) 2008-2009 by Eike Hein <hein@kde.org>
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
@@ -35,6 +35,7 @@
 #include <QHBoxLayout>
 #include <QLabel>
 #include <QWidget>
+
 #include <QKeyEvent>
 
 
@@ -45,6 +46,8 @@ Terminal::Terminal(QWidget* parent) : QObject(parent)
     m_terminalId = m_availableTerminalId;
     m_availableTerminalId++;
 
+    m_keyboardInputEnabled = true;
+
     m_part = NULL;
     m_terminalInterface = NULL;
     m_partWidget = NULL;
@@ -95,13 +98,36 @@ void Terminal::deletePart()
 bool Terminal::eventFilter(QObject* /* watched */, QEvent* event)
 {
     if (event->type() == QEvent::FocusIn)
-        emit activated (m_terminalId);
+    {
+        emit activated(m_terminalId);
+
+        QFocusEvent* focusEvent = static_cast<QFocusEvent*>(event);
+
+        if (focusEvent->reason() == Qt::MouseFocusReason || focusEvent->reason() == Qt::OtherFocusReason
+                || focusEvent->reason() == Qt::BacktabFocusReason)
+            emit manuallyActivated(this);
+    }
     else if (event->type() == QEvent::MouseMove)
     {
         if (Settings::focusFollowsMouse() && m_terminalWidget && !m_terminalWidget->hasFocus())
             m_terminalWidget->setFocus();
     }
 
+    if (!m_keyboardInputEnabled)
+    {
+        if (event->type() == QEvent::KeyPress)
+        {
+            QKeyEvent* keyEvent = static_cast<QKeyEvent*>(event);
+
+            if (keyEvent->modifiers() == Qt::NoModifier)
+                emit keyboardInputBlocked(this);
+
+            return true;
+        }
+        else if (event->type() == QEvent::KeyRelease)
+            return true;
+    }
+
     return false;
 }
 
