@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2008 by Eike Hein <hein@kde.org>
+  Copyright (C) 2008-2009 by Eike Hein <hein@kde.org>
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
@@ -55,12 +55,17 @@ class Terminal : public QObject
         void manageProfiles();
         void editProfile();
 
+        bool keyboardInputEnabled() { return m_keyboardInputEnabled; }
+        void setKeyboardInputEnabled(bool enabled) { m_keyboardInputEnabled = enabled; }
+
         void deletePart();
 
 
     signals:
         void titleChanged(int terminalId, const QString& title);
         void activated(int terminalId);
+        void manuallyActivated(Terminal* terminal);
+        void keyboardInputBlocked(Terminal* terminal);
         void destroyed(int terminalId);
 
 
@@ -72,16 +77,20 @@ class Terminal : public QObject
     private:
         void disableOffendingPartActions();
 
+        void displayKPartLoadError();
+
         static int m_availableTerminalId;
         int m_terminalId;
 
         KParts::Part* m_part;
         TerminalInterface* m_terminalInterface;
         QWidget* m_partWidget;
-        QWidget* m_terminalWidget;
+        QPointer<QWidget> m_terminalWidget;
         QWidget* m_parentSplitter;
 
         QString m_title;
+
+        bool m_keyboardInputEnabled;
 };
 
 #endif 
